@@ -10,12 +10,10 @@
 #' present in the dataset (no showing 0).
 #' @param f_fluxid column containing fluxes unique ID
 #' @param f_quality_flag column containing the quality flags
-#' @param f_cut column indicating which part of the flux is being cut
-#' @param cut_arg argument defining that the data point should be cut out
 #' @return a dataframe with the number of fluxes for each quality flags
 #' and their proportion to the total
 #' @importFrom dplyr all_of select group_by summarise
-#' tibble right_join filter distinct
+#' tibble right_join filter distinct arrange desc
 #' @importFrom tidyr replace_na
 #' @author Vincent Belde
 #' @examples
@@ -29,7 +27,6 @@
 flux_flag_count <- function(slopes_df,
                             f_fluxid = f_fluxid,
                             f_quality_flag = f_quality_flag,
-                            f_cut = f_cut,
                             f_flags = c(
                               "ok",
                               "discard",
@@ -40,18 +37,16 @@ flux_flag_count <- function(slopes_df,
                               "force_ok",
                               "force_zero",
                               "force_lm"
-                            ),
-                            cut_arg = "cut") {
+                            )) {
 
   flag_df <- slopes_df |>
-    filter({{f_cut}} != cut_arg) |>
     mutate(
       f_quality_flag = as.factor({{f_quality_flag}})
     ) |>
     select({{f_fluxid}}, {{f_quality_flag}}) |>
     distinct()
 
-  flags <- tibble({{f_quality_flag}} := factor(f_flags, levels = f_flags))
+  flags <- tibble({{f_quality_flag}} := factor(f_flags))
 
   count_table <- flag_df |>
     summarise(
@@ -62,7 +57,8 @@ flux_flag_count <- function(slopes_df,
     mutate(
       n = replace_na(.data$n, 0),
       ratio = .data$n / sum(.data$n)
-    )
+    ) |>
+    arrange(desc(.data$n))
 
   count_table
 }
