@@ -2,8 +2,8 @@
 #' @description specific part of flux_plot for
 #' quadratic fit
 #' @param slopes_df dataset containing slopes
-#' @param conc_col column with gas concentration
-#' @param datetime_col column with datetime of each data point
+#' @param f_conc column with gas concentration
+#' @param f_datetime column with datetime of each data point
 #' @param y_text_position position of the text box
 #' @importFrom dplyr select distinct
 #' @importFrom ggplot2 ggplot aes geom_point geom_line theme_bw
@@ -16,10 +16,10 @@
 
 
 flux_plot_quadratic <- function(slopes_df,
-                                conc_col,
-                                datetime_col,
+                                f_conc,
+                                f_datetime,
                                 y_text_position) {
-  param_df <- flux_param_qua(slopes_df, {{conc_col}})
+  param_df <- flux_param_qua(slopes_df, {{f_conc}})
 
   slopes_df <- flux_plot_flag(slopes_df, param_df)
 
@@ -31,11 +31,11 @@ flux_plot_quadratic <- function(slopes_df,
     )
 
   plot_quadratic <- slopes_df |>
-    ggplot(aes({{datetime_col}})) +
+    ggplot(aes({{f_datetime}})) +
     theme_bw() +
     geom_vline(xintercept = slopes_df$f_start_z,
                color = "grey", linewidth = 0.5) +
-    geom_point(aes(y = {{conc_col}}, color = .data$f_quality_flag),
+    geom_point(aes(y = {{f_conc}}, color = .data$f_quality_flag),
       size = 0.2,
       na.rm = TRUE
     ) +
