@@ -187,20 +187,6 @@ flux_quality <- function(slopes_df,
   name_conc <- names(select(slopes_df, {{f_conc}}))
 
 
-  slopes_df <- slopes_df |>
-    mutate(
-      f_n_conc = sum(!is.na(.data[[name_conc]])),
-      f_ratio = .data$f_n_conc / int_length(interval({{f_start}}, {{f_end}})),
-      f_flag_ratio = case_when(
-        .data$f_ratio == 0 ~ "no_data",
-        .data$f_ratio <= ratio_threshold ~ "too_low",
-        TRUE ~ "ok"
-      ),
-      f_min_slope = (2 * instr_error) / max({{f_time}}),
-      .by = c({{f_fluxid}}, {{f_cut}})
-    )
-
-
 
   quality_par_start <- slopes_df |>
     # for the start error we take the entire flux into account
@@ -221,9 +207,32 @@ flux_quality <- function(slopes_df,
   slopes_df <- slopes_df |>
     left_join(quality_par_start, by = join_by({{f_fluxid}}))
 
+
+  slopes_keep <- slopes_df |>
+    filter(
+      {{f_cut}} != cut_arg
+    ) |>
+    mutate(
+      f_n_conc = sum(!is.na(.data[[name_conc]])),
+      f_ratio = .data$f_n_conc / int_length(interval({{f_start}}, {{f_end}})),
+      f_flag_ratio = case_when(
+        .data$f_ratio == 0 ~ "no_data",
+        .data$f_ratio <= ratio_threshold ~ "too_low",
+        TRUE ~ "ok"
+      ),
+      f_min_slope = (2 * instr_error) / max({{f_time}}),
+      .by = c({{f_fluxid}}, {{f_cut}})
+    )
+
+  slopes_cut <- slopes_df |>
+    filter(
+      {{f_cut}} == cut_arg
+    )
+
+
   if (kappamax == TRUE) {
-    slopes_df <- flux_quality_kappamax(
-      slopes_df,
+    slopes_keep <- flux_quality_kappamax(
+      slopes_keep,
       f_slope = {{f_slope}},
       f_fluxid = {{f_fluxid}},
       f_fit = {{f_fit}},
@@ -236,19 +245,17 @@ flux_quality <- function(slopes_df,
       name_df = name_df
     )
 
-    quality_flag_lm <- slopes_df |>
+    quality_flag_lm <- slopes_keep |>
       filter(.data$f_model == "linear")
 
-    quality_flag_exp <- slopes_df |>
+    quality_flag_exp <- slopes_keep |>
       filter(str_detect(.data$f_model, "exp"))
 
     if (nrow(quality_flag_lm) > 0) {
       quality_flag_lm <- flux_quality_lm(
         slopes_df = quality_flag_lm,
-        f_conc = {{f_conc}},
         f_fluxid = {{f_fluxid}},
         f_slope = {{f_slope}},
-        f_cut = {{f_cut}},
         f_pvalue = {{f_pvalue}},
         f_rsquared = {{f_rsquared}},
         force_discard = force_discard,
@@ -268,7 +275,6 @@ flux_quality <- function(slopes_df,
         {{f_slope}},
         {{f_time}},
         {{f_fit}},
-        {{f_cut}},
         {{f_slope_lm}},
         {{f_b}},
         force_discard = force_discard,
@@ -289,13 +295,12 @@ flux_quality <- function(slopes_df,
 
   if (str_detect(fit_type, "exp") && kappamax == FALSE) {
     quality_flag <- flux_quality_exp(
-      slopes_df,
+      slopes_keep,
       {{f_conc}},
       {{f_fluxid}},
       {{f_slope}},
       {{f_time}},
       {{f_fit}},
-      {{f_cut}},
       {{f_slope_lm}},
       {{f_b}},
       force_discard = force_discard,
@@ -311,11 +316,9 @@ flux_quality <- function(slopes_df,
   }
 
   if (fit_type == "quadratic" && kappamax == FALSE) {
-    quality_flag <- flux_quality_qua(slopes_df,
-      {{f_conc}},
+    quality_flag <- flux_quality_qua(slopes_keep,
       {{f_fluxid}},
       {{f_slope}},
-      {{f_cut}},
       {{f_pvalue}},
       {{f_rsquared}},
       {{f_slope_lm}},
@@ -332,11 +335,9 @@ flux_quality <- function(slopes_df,
 
 
   if (fit_type == "linear") {
-    quality_flag <- flux_quality_lm(slopes_df,
-      {{f_conc}},
+    quality_flag <- flux_quality_lm(slopes_keep,
       {{f_fluxid}},
       {{f_slope}},
-      {{f_cut}},
       {{f_pvalue}},
       {{f_rsquared}},
       force_discard = force_discard,
@@ -349,8 +350,7 @@ flux_quality <- function(slopes_df,
   }
 
   flag_count <- flux_flag_count(
-    quality_flag,
-    cut_arg = cut_arg
+    quality_flag
   )
 
   flag_msg <- flag_count |>
@@ -362,7 +362,7 @@ flux_quality <- function(slopes_df,
     ) |>
     pull(message)
 
-  total_nb <- slopes_df |>
+  total_nb <- quality_flag |>
     select({{f_fluxid}}) |>
     distinct() |>
     nrow()
@@ -370,6 +370,9 @@ flux_quality <- function(slopes_df,
   message(paste("\n", "Total number of measurements:", total_nb))
   message(flag_msg)
 
+  quality_flag <- bind_rows(quality_flag, slopes_cut) |>
+    arrange({{f_fluxid}}, {{f_time}})
+
   attr(quality_flag, "fit_type") <- {{fit_type}}
 
   quality_flag
